<?php

namespace Drupal\simple_account_policy\Controller;

use Drupal\simple_account_policy\AccountPolicyInterface;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;

/**
 * Class AccountPolicyController
 */
class AccountPolicyController extends ControllerBase {

  /**
   * The account policy.
   *
   * @var AccountPolicyInterface
   */
  protected $account_policy;

  /**
   * ModalFormContactController constructor.
   *
   * @param \Drupal\Core\Form\FormBuilder $form_builder
   *   The form builder.
   */
  public function __construct(AccountPolicyInterface $accountPolicy) {
    $this->account_policy = $accountPolicy;
  }

  /**
   * {@inheritdoc}
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The Drupal service container.
   *
   * @return static
   */
  public static function create(ContainerInterface $container) {

    /** @var \Drupal\simple_account_policy\AccountPolicyInterface $account_policy */
    $account_policy = $container->get('simple_account_policy');

    return new static(
      $account_policy
    );
  }

  /**
   * Activate the given user.
   *
   * @param $user
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   */
  public function activate($user) {

    $this->account_policy->activate($user);

    return new RedirectResponse(\Drupal::destination()->get());
  }

  /**
   * Block the given user.
   *
   * @param $user
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   */
  public function block($user) {

    $this->account_policy->block($user);

    return new RedirectResponse(\Drupal::destination()->get());
  }
}
